pub struct ProposeArgs<B: BlockT> {
pub inherent_data: InherentData,
pub inherent_digests: Digest,
pub max_duration: Duration,
pub block_size_limit: Option<usize>,
pub storage_proof_recorder: Option<ProofRecorder<B>>,
pub extra_extensions: Extensions,
}Expand description
Arguments for Proposer::propose.
Fields
inherent_data: InherentDataThe inherent data to pass to the block production.
inherent_digests: DigestThe inherent digests to include in the produced block.
max_duration: DurationMax duration for building the block.
block_size_limit: Option<usize>Optional size limit for the produced block.
When set, block production ends before hitting this limit. The limit includes the storage proof, when proof recording is activated.
storage_proof_recorder: Option<ProofRecorder<B>>Optional proof recorder for recording storage proofs during block production.
When Some, the recorder will be used on block production to record all storage accesses.
extra_extensions: ExtensionsExtra extensions for the runtime environment.